# cdk-chalice

[![PyPI Version](https://badge.fury.io/py/cdk-chalice.svg)](https://badge.fury.io/py/cdk-chalice)
[![Downloads](https://img.shields.io/pypi/dm/cdk-chalice.svg)](https://pypi.org/project/cdk-chalice/)
[![Documentation Status](https://readthedocs.org/projects/cdk-chalice/badge/?version=latest)](https://cdk-chalice.readthedocs.io/en/latest/?badge=latest)
[![Contributors](https://img.shields.io/github/contributors/alexpulver/cdk-chalice.svg)](https://github.com/alexpulver/cdk-chalice/graphs/contributors)

**AWS CDK construct for AWS Chalice**

This library allows to include an [AWS Chalice](https://chalice.readthedocs.io/en/latest/) 
application into a broader [AWS Cloud Development Kit](https://docs.aws.amazon.com/cdk/latest/guide/home.html)
(AWS CDK) application.

See API documentation on Read the Docs: https://cdk-chalice.readthedocs.io/en/latest/

**Installation**

Install and update using [pip](https://pip.pypa.io/en/stable/installing/):
```bash
pip install -U cdk-chalice
```
